abacusai.external_application — AbacusAI documentation

# `abacusai.external_application`

## Module Contents

### Classes

`ExternalApplication` | An external application.

class abacusai.external_application.ExternalApplication(client, name=None, externalApplicationId=None, deploymentId=None, logo=None, theme=None, userGroupIds=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An external application.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the external application.

    - externalApplicationId (str) – The unique identifier of the external application.

    - deploymentId (str) – The deployment id associated with the external application.

    - logo (str) – The logo.

    - theme (dict) – The theme used for the External Application.

    - userGroupIds (list) – A list of App User Groups with access to this external application

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  update(name=None, logo=None, theme=None)

    Updates an External Application.

    Parameters:

      - name (str) – The name of the External Application.

      - logo (str) – The logo to be displayed.

      - theme (dict) – The visual theme of the External Application.

    Returns:

      The updated External Application.

    Return type:

      ExternalApplication

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      ExternalApplication

  describe()

    Describes an External Application.

    Parameters:

      external_application_id (str) – The ID of the External Application.

    Returns:

      The External Application.

    Return type:

      ExternalApplication

  delete()

    Deletes an External Application.

    Parameters:

      external_application_id (str) – The ID of the External Application.